'''
Author: Liu Yancheng
Description: test
Date: 2022-01-16 20:05:40
LastEditTime: 2022-01-24 18:40:15
FilePath: \myImport\valueInfo.py
'''


import numpy as np
from PIL import Image


class valueInfo():

    def __init__(self, param=None):
        self.param = param

    def show(self, data):
        # print("dataType")证明在这里修改以后，直接在终端运行，是可以直接修改的，不需要重启终端
        dataType = type(data)

        if(dataType == str or dataType == list):
            self.forList(data)

        elif(dataType == dict):
            self.forDict(data)

        elif(dataType == np.ndarray or dataType == "np.ndarray" or dataType == "numpy.ndarray"):
            self.forNParray(data)
        else:
            print("")

    def forNParray(self, theNP):

        print("dataType is: NParray")
        print("NParray shape is:", theNP.shape)
        figure = Image.fromarray(theNP)
        figure.show()

    def forList(self, theList):
        print("dataType is: List")
        print("string length is:"+str(len(theList)))
        if(len(theList) > 5):
            print("top 5 of the list are:", theList[:5])

    def forDict(self, theDict):
        print("dataType is: Dict")
        print("dict key number is:"+str(len(theDict)))
        #print("dict shape is:"+theDict)

        for eachKey in theDict.keys():
            print(str(eachKey)+"\n\ttype is:"+str(type(theDict[eachKey])))
            #print("value shape is:"+theDict[eachKey].shape())
            if(type(theDict[eachKey]) == str or type(theDict[eachKey]) == list):
                print("-------------the string--------------------")
                self.forList(theDict[eachKey])
                print(">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>")

            if(type(theDict[eachKey]) == dict):
                print("-------------the dict----------------------")
                self.forDict(self, theDict[eachKey])
                print(">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>")

            if(type(theDict[eachKey]) == np.ndarray or type(theDict[eachKey]) == "np.ndarray" or type(theDict[eachKey]) == "numpy.ndarray"):
                print("-------------the dict----------------------")
                self.forNParray(theDict[eachKey])
                print(">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>")


if __name__ == "__main__":
    val = valueInfo()
    a = {"name": "sss",
         "age": 19}
    b = "aaaaaaa"

    val.show(b)



'''
Author: your name
Date: 2022-01-17 17:10:42
LastEditTime: 2022-01-29 12:15:00
LastEditors: Liu Yancheng
Description: 
FilePath: \myImport\__init__.py
'''

from myImport.valueInfo import valueInfo

__version__ = "0.0.1"
__description__="for looking up information of values"
__author__ = "Liu Yancheng"
__author_email__ = "Liu Yancheng"
__url__ = "http://gitee.com/qq1418381215/myImport"
# __init__.py 文件定义了包的属性和方法。其实它可以什么也不定义；可以只是一个空文件，但是必须存在。
# 如果 __init__.py 不存在，这个目录就仅仅是一个目录，而不是一个包，它就不能被导入或者包含其它的模块和嵌套包。

'''
.
└── mypackage
    ├── subpackage_1
    │   ├── test11.py
    │   └── test12.py
    ├── subpackage_2
    │   ├── test21.py
    │   └── test22.py
    └── subpackage_3
        ├── test31.py
        └── test32.py
    
没有这个文件：
from mypackage.subpackage_1 import test11
from mypackage.subpackage_1 import test12
from mypackage.subpackage_2 import test21
from mypackage.subpackage_2 import test22
from mypackage.subpackage_3 import test31
from mypackage.subpackage_3 import test32


有这个文件：
.
└── mypackage
    ├── __init__.py
    ├── subpackage_1
    │   ├── test11.py
    │   └── test12.py
    ├── subpackage_2
    │   ├── test21.py
    │   └── test22.py
    └── subpackage_3
        ├── test31.py
        └── test32.py
        
在init里面写
from mypackage.subpackage_1 import test11
注意这里还是要从根目录写起
则import mypackage的时候，就会导入这个test11了


在init里面写__all__ = ['subpackage_1', 'subpackage_2']
则写from mypackage import *的时候，就会有'subpackage_1', 'subpackage_2'
等价于from mypackage import subpackage_1, subpackage_2

所以可以写__all__ = ['os', 'sys', 're', 'urllib']

没有from
import subpackage1.a # 将模块subpackage.a导入全局命名空间，例如访问a中属性时用subpackage1.a.attr

有from
from subpackage1 import a #　将模块a导入全局命名空间，例如访问a中属性时用a.attr_a
from subpackage.a import attr_a # 将模块a的属性直接导入到命名空间中，例如访问a中属性时直接用attr_a 

使用from语句可以把模块直接导入当前命名空间，from语句并不引用导入对象的命名空间，而是将被导入对象直接引入当前命名空间。


对于函数
import arithmetic.add
import arithmetic.sub as sub

from arithmetic.mul import mul
from arithmetic import dev

def letscook(x, y, oper):
    r = 0
    if oper == "+":
        r = arithmetic.add.add(x, y)
    elif oper == "-":
        r = sub.sub(x, y)
    elif oper == "*":
        r = mul(x, y)
    else:
        r = dev.dev(x, y)
'''



'''
Author: Liu Yancheng
Description: test
Date: 2022-01-29 12:15:08
LastEditTime: 2022-01-29 14:49:59
LastEditors: Liu Yancheng
'''

try:
    from setuptools import setup, find_packages
except ImportError:
    from distutils.core import setup, find_packages
    
import os
import codecs

here = os.path.abspath(os.path.dirname(__file__))
with codecs.open(os.path.join(here, 'README.md'),encoding='utf-8') as fh:
    long_description="\n"+fh.read()

VERSION ="0.0.1"
DESCRIPTION =""
LONG_DESCRIPTION =""

setup(
    name="myImport",
    version=VERSION,
    author="Liu Yancheng",
    author_email="1418381215@qq.com",
    url="https://gitee.com/qq1418381215/myImport",
    description=DESCRIPTION,
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=find_packages(),
    install_requires=["numpy"],
    keywords=["value"]
)
